package com.atguigu.lease.web.admin.interceptor;

import com.atguigu.lease.common.utils.JwtUtil;
import com.atguigu.lease.common.utils.LoginUser;
import com.atguigu.lease.common.utils.LoginUserContext;
import io.jsonwebtoken.Claims;
import jakarta.servlet.http.HttpServletRequest;
import jakarta.servlet.http.HttpServletResponse;
import org.springframework.lang.Nullable;
import org.springframework.stereotype.Component;
import org.springframework.web.servlet.HandlerInterceptor;

@Component
public class AuthenticationInterceptor implements HandlerInterceptor {

    //之前执行
    @Override
    public boolean preHandle(HttpServletRequest request,
                             HttpServletResponse response,
                             Object handler) throws Exception {
        //进行是否登录判断
        //1 获取请求头token  access-token和前端一致
        String token = request.getHeader("access-token");

        //String token = "abdcds";
        //String token = "eyJhbGciOiJIUzI1NiIsInppcCI6IkdaSVAifQ.H4sIAAAAAAAA_6tWKi5NUrJSCg12DYr39HPzV9JRSq0oULIyNDexMLWwNDEx1FEqLU4t8kxRsrKEMPMSc1OBWnJKkyuVagENPxd4QQAAAA.a1GC3ew6N35MURDSHjDUUcD05M7BLJS8-jBS1ovOwHM";

        //2 判断token是否为空，如果空，提示用户
        if(token == null) {
            throw new RuntimeException();
        } else { //3 如果不为空，解析token
            Claims claims = JwtUtil.parseToken(token);
            Long userId = claims.get("userId",Long.class);
            String username = claims.get("username", String.class);
            //TODO 解析token成功之后，根据userId查询数据库，用户是否正常

            //把userId放到ThreadLocal里面
            LoginUser loginUser = new LoginUser();
            loginUser.setUserId(userId);
            loginUser.setUsername(username);
            LoginUserContext.setLoginUser(loginUser);
        }
        return true;
    }

    //清除ThreadLocal值，防止内存泄漏
    @Override
    public void afterCompletion(HttpServletRequest request, HttpServletResponse response, Object handler, @Nullable Exception ex) throws Exception {
        LoginUserContext.clear();
    }

}