package com.atguigu.lease.web.admin.service.impl;

import com.atguigu.lease.model.entity.*;
import com.atguigu.lease.web.admin.mapper.*;
import com.atguigu.lease.web.admin.service.LeaseAgreementService;
import com.atguigu.lease.web.admin.vo.agreement.AgreementQueryVo;
import com.atguigu.lease.web.admin.vo.agreement.AgreementVo;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * @author liubo
 * @description 针对表【lease_agreement(租约信息表)】的数据库操作Service实现
 * @createDate 2023-07-24 15:48:00
 */



@Service
public class LeaseAgreementServiceImpl extends ServiceImpl<LeaseAgreementMapper, LeaseAgreement>
        implements LeaseAgreementService {
    @Autowired
    private LeaseAgreementMapper  leaseAgreementMapper;
    @Autowired
    private ApartmentInfoMapper apartmentInfoMapper;
    @Autowired
    private RoomInfoMapper roomInfoMapper;
    @Autowired
    private PaymentTypeMapper paymentTypeMapper;
    @Autowired
    private LeaseTermMapper leaseTermMapper;
    @Override
    public IPage<AgreementVo> selectPageAgreement(Page<AgreementVo> page, AgreementQueryVo queryVo) {
        IPage<AgreementVo> agreementVoIPage = leaseAgreementMapper.selectPageAgreement(page, queryVo);
        return agreementVoIPage;
    }

    @Override
    public AgreementVo getAgreement(Long id) {
        LeaseAgreement leaseAgreement = leaseAgreementMapper.selectById(id);
        if(leaseAgreement == null) {
            return null;
        }
        //根据公寓id查询公寓信息
        ApartmentInfo apartmentInfo =
                apartmentInfoMapper.selectById(leaseAgreement.getApartmentId());

        //根据房间id获取签约房间信息
        RoomInfo roomInfo =
                roomInfoMapper.selectById(leaseAgreement.getRoomId());

        //支付方式
        PaymentType paymentType =
                paymentTypeMapper.selectById(leaseAgreement.getPaymentTypeId());

        //租期
        LeaseTerm leaseTerm =
                leaseTermMapper.selectById(leaseAgreement.getLeaseTermId());

        //封装到AgreementVo
        AgreementVo agreementVo = new AgreementVo();
        BeanUtils.copyProperties(leaseAgreement,agreementVo);
        agreementVo.setApartmentInfo(apartmentInfo);
        agreementVo.setRoomInfo(roomInfo);
        agreementVo.setPaymentType(paymentType);
        agreementVo.setLeaseTerm(leaseTerm);

        return agreementVo;
    }
}




