package com.atguigu.lease.web.admin.service.impl;

import com.atguigu.lease.model.entity.*;
import com.atguigu.lease.model.enums.ItemType;
import com.atguigu.lease.web.admin.mapper.*;
import com.atguigu.lease.web.admin.service.*;
import com.atguigu.lease.web.admin.vo.attr.AttrValueVo;
import com.atguigu.lease.web.admin.vo.graph.GraphVo;
import com.atguigu.lease.web.admin.vo.room.RoomDetailVo;
import com.atguigu.lease.web.admin.vo.room.RoomItemVo;
import com.atguigu.lease.web.admin.vo.room.RoomQueryVo;
import com.atguigu.lease.web.admin.vo.room.RoomSubmitVo;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;

import java.util.ArrayList;
import java.util.List;

/**
 * @author liubo
 * @description 针对表【room_info(房间信息表)】的数据库操作Service实现
 * @createDate 2023-07-24 15:48:00
 */
@Service
public class RoomInfoServiceImpl extends ServiceImpl<RoomInfoMapper, RoomInfo>
        implements RoomInfoService {

    @Autowired
    private ApartmentInfoService apartmentInfoService;
    @Autowired
    private RoomInfoMapper roomInfoMapper;
    @Autowired
    private RoomAttrValueService roomAttrValueService;
    @Autowired
    private RoomFacilityService roomFacilityService;
    @Autowired
    private RoomLabelService roomLabelService;
    @Autowired
    private GraphInfoService graphInfoService;
    @Autowired
    private RoomPaymentTypeService roomPaymentTypeService;
    @Autowired
    private RoomLeaseTermService roomLeaseTermService;
    @Autowired
    private GraphInfoMapper graphInfoMapper;
    @Autowired
    private AttrValueMapper attrValueMapper;
    @Autowired
    private LabelInfoMapper labelInfoMapper;
    @Autowired
    private PaymentTypeMapper paymentTypeMapper;
    @Autowired
    private LeaseTermMapper leaseTermMapper;


    @Autowired
    private FacilityInfoMapper facilityInfoMapper;


    @Override
    public void saveOrUpdateRoomInfo(RoomSubmitVo roomSubmitVo) {
        Long id = roomSubmitVo.getId();
        this.saveOrUpdate(roomSubmitVo);
        if (id != null) {
            LambdaQueryWrapper<RoomFacility> Wrapper1 = new LambdaQueryWrapper<>();
            Wrapper1.eq(RoomFacility::getRoomId, roomSubmitVo.getId());
            roomFacilityService.remove(Wrapper1);

            LambdaQueryWrapper<RoomAttrValue> Wrapper2 = new LambdaQueryWrapper<>();
            Wrapper2.eq(RoomAttrValue::getRoomId, roomSubmitVo.getId());
            roomAttrValueService.remove(Wrapper2);

            LambdaQueryWrapper<RoomLabel> Wrapper3 = new LambdaQueryWrapper<>();
            Wrapper3.eq(RoomLabel::getRoomId, roomSubmitVo.getId());
            roomLabelService.remove(Wrapper3);

            LambdaQueryWrapper<RoomPaymentType> Wrapper4 = new LambdaQueryWrapper<>();
            Wrapper4.eq(RoomPaymentType::getRoomId, roomSubmitVo.getId());
            roomPaymentTypeService.remove(Wrapper4);

            LambdaQueryWrapper<RoomLeaseTerm> Wrapper5 = new LambdaQueryWrapper<>();
            Wrapper5.eq(RoomLeaseTerm::getRoomId, roomSubmitVo.getId());
            roomLeaseTermService.remove(Wrapper5);

            LambdaQueryWrapper<GraphInfo> Wrapper6 = new LambdaQueryWrapper<>();
            Wrapper6.eq(GraphInfo::getItemId, roomSubmitVo.getId());
            Wrapper6.eq(GraphInfo::getItemType, ItemType.ROOM);
            graphInfoService.remove(Wrapper6);
        }

        // 配套信息添加数据
        List<Long> facilityInfoIds = roomSubmitVo.getFacilityInfoIds();
        if (!CollectionUtils.isEmpty(facilityInfoIds)) {
            List<RoomFacility> roomFacilityList = new ArrayList<>();
            for (Long facilityInfoId : facilityInfoIds) {
                RoomFacility roomFacility = new RoomFacility();
                roomFacility.setRoomId(roomSubmitVo.getId());
                roomFacility.setFacilityId(facilityInfoId);
                roomFacilityList.add(roomFacility);
            }
            roomFacilityService.saveBatch(roomFacilityList);
        }

        List<Long> labelInfoIds = roomSubmitVo.getLabelInfoIds();
        if (!CollectionUtils.isEmpty(labelInfoIds)) {
            List<RoomLabel> roomLabelList = new ArrayList<>();
            for (Long labelInfoId : labelInfoIds) {
                RoomLabel roomLabel = new RoomLabel();
                roomLabel.setRoomId(roomSubmitVo.getId());
                roomLabel.setLabelId(labelInfoId);
                roomLabelList.add(roomLabel);
            }
            roomLabelService.saveBatch(roomLabelList);
        }

        List<Long> attrValueIds = roomSubmitVo.getAttrValueIds();
        if (!CollectionUtils.isEmpty(attrValueIds)) {
            List<RoomAttrValue> roomAttrValueList = new ArrayList<>();
            for (Long attrValueId : attrValueIds) {
                RoomAttrValue roomAttrValue = new RoomAttrValue();
                roomAttrValue.setRoomId(roomSubmitVo.getId());
                roomAttrValue.setAttrValueId(attrValueId);
                roomAttrValueList.add(roomAttrValue);
            }
            roomAttrValueService.saveBatch(roomAttrValueList);
        }
        List<Long> paymentTypeIds = roomSubmitVo.getPaymentTypeIds();
        if (!CollectionUtils.isEmpty(paymentTypeIds)) {
            List<RoomPaymentType> roomPaymentTypeList = new ArrayList<>();
            for (Long paymentTypeId : paymentTypeIds) {
                RoomPaymentType roomPaymentType = new RoomPaymentType();
                roomPaymentType.setRoomId(roomSubmitVo.getId());
                roomPaymentType.setPaymentTypeId(paymentTypeId);
                roomPaymentTypeList.add(roomPaymentType);
            }
            roomPaymentTypeService.saveBatch(roomPaymentTypeList);
        }

        List<GraphVo> graphVoList = roomSubmitVo.getGraphVoList();
        if (!CollectionUtils.isEmpty(graphVoList)) {
            List<GraphInfo> graphInfoList = new ArrayList<>();
            for (GraphVo graphVo : graphVoList) {
                GraphInfo graphInfo = new GraphInfo();
                graphInfo.setItemId(roomSubmitVo.getId());
                graphInfo.setItemType(ItemType.ROOM);
                graphInfo.setName(graphVo.getName());
                graphInfo.setUrl(graphVo.getUrl());
                graphInfoList.add(graphInfo);
            }
            graphInfoService.saveBatch(graphInfoList);
        }
        List<Long> leaseTermIds = roomSubmitVo.getLeaseTermIds();
        if (!CollectionUtils.isEmpty(leaseTermIds)) {
            List<RoomLeaseTerm> roomLeaseTermList = new ArrayList<>();
            for (Long leaseTermId : leaseTermIds) {
                RoomLeaseTerm roomLeaseTerm = new RoomLeaseTerm();
                roomLeaseTerm.setRoomId(roomSubmitVo.getId());
                roomLeaseTerm.setLeaseTermId(leaseTermId);
                roomLeaseTermList.add(roomLeaseTerm);
            }
            roomLeaseTermService.saveBatch(roomLeaseTermList);
        }
    }

    @Override
    public IPage<RoomItemVo> selectRoomInfoPage(Page<RoomItemVo> page, RoomQueryVo queryVo) {
        IPage<RoomItemVo> roomItemVoIPage = roomInfoMapper.selectRoomInfoPage(page, queryVo);
        return roomItemVoIPage;
    }

    @Override
    public RoomDetailVo getDetailById(Long id) {
        RoomInfo roomInfo = new RoomInfo();
        if (roomInfo == null) {
            return null;
        }
        Long apartmentId = roomInfo.getApartmentId();
        ApartmentInfo apartmentInfo = apartmentInfoService.getById(apartmentId);

        List<FacilityInfo> facilityInfoList = facilityInfoMapper.findFacilityListByRoomId(id);
        List<GraphVo> graphVoList = graphInfoMapper.selectGraphListByRoomId(ItemType.ROOM, id);
        List<AttrValueVo> attrvalueVoList = attrValueMapper.selectListByRoomId(id);
        List<LabelInfo> labelInfoList = labelInfoMapper.selectListByRoomId(id);
        List<PaymentType> paymentTypeList = paymentTypeMapper.selectListByRoomId(id);
        List<LeaseTerm> leaseTermList = leaseTermMapper.selectListByRoomId(id);

        RoomDetailVo adminRoomDetailVo = new RoomDetailVo();
        BeanUtils.copyProperties(roomInfo, adminRoomDetailVo);

        adminRoomDetailVo.setApartmentInfo(apartmentInfo);
        adminRoomDetailVo.setGraphVoList(graphVoList);
        adminRoomDetailVo.setAttrValueVoList(attrvalueVoList);
        adminRoomDetailVo.setFacilityInfoList(facilityInfoList);
        adminRoomDetailVo.setLabelInfoList(labelInfoList);
        adminRoomDetailVo.setPaymentTypeList(paymentTypeList);
        adminRoomDetailVo.setLeaseTermList(leaseTermList);

        return adminRoomDetailVo;


    }

    @Override
    public void removeRoomById(Long id) {
        this.removeById(id);


        LambdaQueryWrapper<RoomFacility> wrapper1 = new LambdaQueryWrapper<>();
        wrapper1.eq(RoomFacility::getRoomId,id);
        roomFacilityService.remove(wrapper1);


        LambdaQueryWrapper<RoomLabel> wrapper2 = new LambdaQueryWrapper<>();
        wrapper2.eq(RoomLabel::getRoomId,id);
        roomLabelService.remove(wrapper2);


        LambdaQueryWrapper<RoomAttrValue> wrapper3 = new LambdaQueryWrapper<>();
        wrapper3.eq(RoomAttrValue::getRoomId,id);
        roomAttrValueService.remove(wrapper3);

        LambdaQueryWrapper<RoomPaymentType> wrapper4 = new LambdaQueryWrapper<>();
        wrapper4.eq(RoomPaymentType::getRoomId,id);
        roomPaymentTypeService.remove(wrapper4);

        LambdaQueryWrapper<RoomLeaseTerm> wrapper5 = new LambdaQueryWrapper<>();
        wrapper5.eq(RoomLeaseTerm::getRoomId,id);
        roomLeaseTermService.remove(wrapper5);

        LambdaQueryWrapper<GraphInfo> wrapper6 = new LambdaQueryWrapper<>();
        wrapper6.eq(GraphInfo::getItemId,id);
        wrapper6.eq(GraphInfo::getItemType,ItemType.ROOM);
        graphInfoService.remove(wrapper6);

    }


}





